@@ -9,7 +9,7 @@ from pydantic.dataclasses import dataclass
 import json
 import itertools
 
-from string import ascii_lowercase, ascii_uppercase, digits, punctuation
+from string import ascii_lowercase, ascii_uppercase, digits, punctuation, whitespace
 
 #region Helper functions
 
@@ -75,13 +75,13 @@ DEFAULT_CHARSETS: Dict[str,str] = {
   "lower": ascii_lowercase,
   "upper": ascii_uppercase,
   "digits": digits,
-  "symbols": punctuation  
+  "symbols": punctuation + whitespace
 }
 
 ALPHABET_CHARSETS: Dict[str,str] = {
   "alphabet": ascii_lowercase + ascii_uppercase,
   "digits": digits,
-  "symbols": punctuation  
+  "symbols": punctuation + whitespace
 }
 
 def SimplePCP(*args, **kwargs) -> 'PCP':
